package com.ruoyi.system.service.impl;

import java.util.List;

import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.StudentInfoMapper;
import com.ruoyi.system.domain.StudentInfo;
import com.ruoyi.system.service.IStudentInfoService;

/**
 * 学生档案信息Service业务层处理
 * 
 * @author ruoyi
 * @date 2023-07-21
 */
@Service
public class StudentInfoServiceImpl implements IStudentInfoService 
{
    @Autowired
    private StudentInfoMapper studentInfoMapper;

    /**
     * 查询学生档案信息
     * 
     * @param id 学生档案信息主键
     * @return 学生档案信息
     */
    @Override
    public StudentInfo selectStudentInfoById(Long id)
    {
        return studentInfoMapper.selectStudentInfoById(id);
    }

    /**
     * 查询学生档案信息列表
     * 
     * @param studentInfo 学生档案信息
     * @return 学生档案信息
     */
    @Override
    public List<StudentInfo> selectStudentInfoList(StudentInfo studentInfo)
    {
        return studentInfoMapper.selectStudentInfoList(studentInfo);
    }

    /**
     * 新增学生档案信息
     * 
     * @param studentInfo 学生档案信息
     * @return 结果
     */
    @Override
    public AjaxResult insertStudentInfo(StudentInfo studentInfo)
    {
        //查询数据库是否存在信息
        StudentInfo student = new StudentInfo();
        student.setStudentId(studentInfo.getStudentId());
        List<StudentInfo> studentInfos = studentInfoMapper.selectStudentInfoList(student);
        if(studentInfos!=null && studentInfos.size()>0){
            return AjaxResult.error("参数错误");
        }
        studentInfo.setCreateTime(DateUtils.getNowDate());
        int rows = studentInfoMapper.insertStudentInfo(studentInfo);
        return rows > 0 ? AjaxResult.success() : AjaxResult.error();

    }

    /**
     * 修改学生档案信息
     * 
     * @param studentInfo 学生档案信息
     * @return 结果
     */
    @Override
    public int updateStudentInfo(StudentInfo studentInfo)
    {
        studentInfo.setUpdateTime(DateUtils.getNowDate());
        return studentInfoMapper.updateStudentInfo(studentInfo);
    }

    /**
     * 批量删除学生档案信息
     * 
     * @param ids 需要删除的学生档案信息主键
     * @return 结果
     */
    @Override
    public int deleteStudentInfoByIds(Long[] ids)
    {
        return studentInfoMapper.deleteStudentInfoByIds(ids);
    }

    /**
     * 删除学生档案信息信息
     * 
     * @param id 学生档案信息主键
     * @return 结果
     */
    @Override
    public int deleteStudentInfoById(Long id)
    {
        return studentInfoMapper.deleteStudentInfoById(id);
    }
}
